form/form_builder library

Mixins

FormBuilder<T>
FormBuilder is a helper class to handle forms. T stands for the type used to identify the fields such as an enum or a string to later access each of its fields.