inputMap property
The map of fields, along with all of their properties
Implementation
@observable
final ObservableMap<T, FormItem> inputMap = <T, FormItem>{}.asObservable();
The map of fields, along with all of their properties
@observable
final ObservableMap<T, FormItem> inputMap = <T, FormItem>{}.asObservable();