isValid property
The state of the field, valid or invalid - it will always start as invalid until the first validation happens
Implementation
final bool isValid;
The state of the field, valid or invalid - it will always start as invalid until the first validation happens
final bool isValid;