updateField method
- @action
- dynamic newValue,
- T type
Updates the value of the field without validating it, this does not update the computed variable isFormValid
Implementation
@action
void updateField(dynamic newValue, T type) {
inputMap[type] = inputMap[type]!.updateValue(newValue);
}