ValidatorResult class
ValidatorResult is a helper class designed to help Validator implementations always return the same object type.
Constructors
- ValidatorResult({required bool isValid, String? errorMessage})
-
This is the constructor of the class
const
- ValidatorResult.success()
-
This is a helper method to return a successful validation result
factory
Properties
- errorMessage → String?
-
The error message of the field
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isValid → bool
-
The state of the field, valid or invalid
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override